// 完毕：
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;

namespace DsPdfWeb.Demos.Basics
{
    // 创建简单的 3 列文本布局。
    // 稍微复杂但实际上更有用的方法
    // 要呈现列中的文本，请参阅BalancedColumns。
    public class MultiColumnText
    {
        public int CreatePDF(Stream stream)
        {
            var doc = new GcPdfDocument();
            var g = doc.NewPage().Graphics;
            var tl = g.CreateTextLayout();
            tl.DefaultFormat.Font = StandardFonts.Times;
            tl.DefaultFormat.FontSize = 12;
            tl.TextAlignment = TextAlignment.Justified;
            tl.FirstLineIndent = 72 / 2;
            tl.ParagraphSpacing = 72 / 8;
            // 添加一些文本（请注意，TextLayout 将“\r\n”解释为段落分隔符）：
            tl.Append(Common.Util.LoremIpsum(20));
            // 设置栏目：
            const int colCount = 3;
            // 周围 1/2" 边距：
            const float margin = 72 / 2;
            // 列间 1/4" 间隙：
            const float colGap = margin / 4;
            float colWidth = (doc.Pages.Last.Size.Width - margin * 2) / colCount - colGap * (colCount - 1);
            tl.MaxWidth = colWidth;
            tl.MaxHeight = doc.Pages.Last.Size.Height - margin * 2;
            // 计算字形并对整个文本进行布局：
            tl.PerformLayout(true);
            // 在循环中，拆分并渲染当前列中的文本：
            int col = 0;
            while (true)
            {
                // 'rest' 将接受不适合的文本：
                var splitResult = tl.Split(null, out TextLayout rest);
                g.DrawTextLayout(tl, new PointF(margin + col * (colWidth + colGap), margin));
                if (splitResult != SplitResult.Split)
                    break;
                tl = rest;
                if (++col == colCount)
                {
                    doc.Pages.Add();
                    g = doc.Pages.Last.Graphics;
                    col = 0;
                }
            }
            // 完毕：
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
